@@ -1719,8 +1719,8 @@ class RawDataApi(metaclass=Singleton):
             try:
                 query = db_session.query(EmStockIpoInfo)
                 df = pd.read_sql(query.statement, query.session.bind).drop(columns=['_update_time']).rename(columns=col_dic)
-                df['股票代码不带市场'] = df.股票代码.map(lambda x : x.split('.')[0])
-                df['申购代码'] = df.申购代码带市场.map(lambda x : x.split('.')[0])
+                df['股票代码不带市场'] = df.股票代码.map(lambda x : x.split('.')[0] if x is not None else None)
+                df['申购代码'] = df.申购代码带市场.map(lambda x : x.split('.')[0] if x is not None else None)
                 df['申购资金上限'] = df['发行价'] * df['申购数量上限']
                 return df
 
@@ -1772,7 +1772,7 @@ class RawDataApi(metaclass=Singleton):
                 df['回售价'] = None if df.回售价格说明 is None else df.发行价格
                 df['赎回价'] = None if df.赎回价格说明 is None else df.发行价格
                 df['申购数量上限'] = df.申购数量限制说明.map(lambda x: int(x.split('网上申购数量上限：')[1].split('手')[0])*10)
-                df['申购代码带市场'] = df.申购代码 + '.' +df.转债代码.map(lambda x: x.split('.')[1])
+                df['申购代码带市场'] = df.申购代码 + '.' +df.转债代码.map(lambda x: x.split('.')[1] if x is not None else None)
                 df = df.drop(columns=['回售价格说明','赎回价格说明'])
                 return df
 
