@@ -78,4 +78,28 @@ class TradeTrigger:
             }
             trigger_result.append(dic)
         
-        return trigger_result
\ No newline at end of file
+        return trigger_result
+
+    @staticmethod
+    def trigger_detail(trigger:int, 
+                    # Ir params
+                    index_rebalance_max_diff:float,
+                    _index_rebalance_max_diff_name:float,
+                    JudgeIndexDiff:float,
+                    #Fs params
+                    fund_selection_min_score:float,
+                    _fund_selection_min_name:str,
+                    JudgeFundSelection:float,
+                    fund_rank_list:list,
+                    #Fr params
+                    fund_rebalance_min_score:float,
+                    _fund_rebalance_min_name:str,
+                    JudgeFundRebalance:float,
+              ):
+        result = {
+            'index_rebalance_detail':   f'index_id {_index_rebalance_max_diff_name} index_rebalance_max_diff: {round(index_rebalance_max_diff,3)} threshold: {JudgeIndexDiff}',
+            'fund_selection':           f'index_id {_fund_selection_min_name} fund_selection_min_score: {round(fund_selection_min_score,3)} threshold: {JudgeFundSelection} fund rank :{fund_rank_list}',
+            'fund_rebalance':           f'index_id {_fund_rebalance_min_name} fund_rebalance_min_score {round(fund_rebalance_min_score,5)} threshold: {JudgeFundRebalance}'
+
+        }
+        return result
\ No newline at end of file
