@@ -1,5 +1,6 @@
 
 import time
+import datetime
 from typing import Tuple, Set, Optional, List
 from collections import defaultdict
 
@@ -11,7 +12,7 @@ from ...wrapper.mysql import RawDatabaseConnector
 ALL_CSI_INDEX_INNER_NAME = '_csi_index_all'
 
 
-class RawDataHelper():
+class RawDataHelper:
     def __init__(self):
         self._updated_count = defaultdict(int)
         self._timer: float = time.monotonic()
@@ -58,20 +59,34 @@ class RawDataHelper():
         lastest_list: pd.Series = index_component.iloc[-1, :]
         last_list: pd.Series = index_component.iloc[-2, :]
         print(f"got two days' index component, (latest){lastest_list.datetime} (prev){last_list.datetime}")
-        return set(lastest_list.stock_list.split(',')).difference(set(last_list.stock_list.split(',')))
+        return set(last_list.stock_list.split(',')).difference(set(lastest_list.stock_list.split(',')))
 
     @staticmethod
     def get_all_live_fund_list(end_date: str) -> Optional[List[str]]:
         fund_list_df = RawDataApi().get_em_fund_list(end_date, limit=1)
-        if fund_list_df is None:
+        if fund_list_df is None or fund_list_df.shape[0] < 1:
             return
         return fund_list_df.all_live_fund_list.array[0].split(',')
 
     @staticmethod
     def get_all_fund_list(end_date: str) -> Optional[List[str]]:
         fund_list_df = RawDataApi().get_em_fund_list(end_date, limit=1)
-        if fund_list_df is None:
+        if fund_list_df is None or fund_list_df.shape[0] < 1:
             return
         fund_list = fund_list_df.all_live_fund_list.array[0].split(',')
         fund_list += fund_list_df.delisted_fund_list.array[0].split(',')
         return fund_list
+
+    @staticmethod
+    def get_prev_target_date(end_date: str, target_date_list: Tuple[str]) -> datetime.date:
+        # 寻找离目前最近且没超过当前时间的财报日期，将数据写在这个日期上（先删掉这个日期上的旧数据）
+        end_date_dt = pd.to_datetime(end_date, infer_datetime_format=True)
+        md = end_date_dt.strftime('%m%d')
+        sentry_date = pd.Series(target_date_list)
+        sentry = sentry_date[sentry_date <= md]
+        if sentry.empty:
+            # 这里取前一年的12月31
+            real_date = datetime.date(end_date_dt.year - 1, 12, 31)
+        else:
+            real_date = pd.to_datetime(str(end_date_dt.year)+sentry.array[-1], infer_datetime_format=True).date()
+        return real_date
