@@ -1,6 +1,7 @@
 import pandas as pd
 import traceback
 import json
+import math
 from sqlalchemy import func
 from .compute_fund_recommendation_collection import FundRecommendationCollectionProcessor
 from ...wrapper.mysql import (RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector, 
@@ -67,6 +68,19 @@ class FundDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed fill get data <err_msg> {}'.format(e))
 
+    def get_fund_mng_list(self):
+        with BasicDatabaseConnector().managed_session() as mn_session:
+            try:
+                query = mn_session.query(
+                    FundInfo.fund_id,
+                    FundInfo.fund_manager,
+                )
+                funds = pd.read_sql(query.statement, query.session.bind)
+                return funds.set_index('fund_id')
+            except Exception as e:
+                print('Failed fill get data <err_msg> {}'.format(e))
+
+
     def get_fund_benchmark_df(self):
         def select_one_benchmark(x):
             if not x:
@@ -516,7 +530,6 @@ class FundDailyCollectionProcessor(object):
                 'mng_id':'top_mng_id'
             }   
             fund_recommend_extend = fund_recommend_extend.set_index(['fund_id','mng_id']).join(_manager_info.set_index(['fund_id','mng_id'])).reset_index().rename(columns=_col).set_index('fund_id')
-
             funds = funds.drop(columns=['manage_fee','trustee_fee'])
             exchange_status = self.get_exchange_status_df().set_index('fund_id')
             print(exchange_status)
@@ -583,7 +596,15 @@ class FundDailyCollectionProcessor(object):
             df = df.sort_values(['fund_id'])
             df = df.dropna(subset=['order_book_id'])
             df.loc[:,'fund_type'] = df.wind_class_II.map(self.fund_type_dic)
-            # df.to_csv('./hhh.csv')
+            
+            # 未纳入评分的基金 补头名基金经理 
+            df = df.set_index('fund_id')
+            _mng_df = self.get_fund_mng_list()
+            for r in df.itertuples():
+                fund_id = r.Index
+                if isinstance(r.top_mng_name,float) and math.isnan(r.top_mng_name):
+                    df.loc[fund_id,'top_mng_name'] = _mng_df.loc[fund_id,'fund_manager']
+            df = df.reset_index()
             self.append_data(FundDailyCollection.__tablename__, df)
 
             print(df)
