@@ -715,7 +715,7 @@ class FundManagerDailyCollection(Base):
     annual_ret_3y_m = Column(DOUBLE(asdecimal=False)) # 近三年年化收益
     mdd_1y_m = Column(DOUBLE(asdecimal=False)) # 近一年最大回撤
     annual_ret_1y_m = Column(DOUBLE(asdecimal=False)) # 近一年年化收益
-    trading_days = Column(DOUBLE(asdecimal=False)) # 从业天数
+    trading_days = Column(Integer) # 从业天数
     best_fund = Column(CHAR(10)) # 代表作品
     company_id = Column(CHAR(64)) # 基金公司
 
