@@ -18,6 +18,7 @@ from ...data.manager.score import ScoreFunc, FundScoreManager
 from ...data.struct import AssetWeight, AssetPrice, AssetPosition, AssetValue, ScoreSelect
 from ...data.struct import FundPosition, TAAParam, AssetTradeParam, FundTradeParam, FAParam, ScoreType
 from ...util.calculator import Calculator
+from ...util.calculator_item import CalculatorBase
 
 class FundEngine:
 
@@ -657,6 +658,14 @@ def four_dimensions_backtest(m,begin_date, end_date, saa, fund_param, taa_detail
         res_i['策略名称'] = port_name
         res.append(res_i)
     stat_df = pd.DataFrame(res).set_index('策略名称').reindex(['沪深300','战略配置','战术配置','优选基金'])#[['annualized_ret','annualized_vol','sharpe','mdd','mdd_date1','mdd_date2']]
+    stat_df['annualized_ret'] = stat_df['annualized_ret'].map(lambda x : CalculatorBase.stat_round_pct(x))
+    stat_df['annualized_vol'] = stat_df['annualized_vol'].map(lambda x : CalculatorBase.stat_round_pct(x))
+    stat_df['worst_3m_ret'] = stat_df['worst_3m_ret'].map(lambda x : CalculatorBase.stat_round_pct(x))
+    stat_df['worst_6m_ret'] = stat_df['worst_6m_ret'].map(lambda x : CalculatorBase.stat_round_pct(x))
+    stat_df['mdd'] = stat_df['mdd'].map(lambda x : CalculatorBase.stat_round_pct(x))
+    stat_df['sharpe'] = stat_df['sharpe'].map(lambda x : round(x,3))
+    stat_df['ret_over_mdd'] = stat_df['ret_over_mdd'].map(lambda x : round(x,3))
+    stat_df[['start_date', 'end_date','annualized_ret', 'annualized_vol', 'sharpe','mdd','mdd_date1','mdd_date2','worst_3m_ret','worst_6m_ret','ret_over_mdd']].rename(columns={'ret_over_mdd':'calmar'})    
     return mv_df, stat_df, fund_annual_ret
 
 def licaimofang_backtest(m: FundDataManager, saa:AssetWeight):
