@@ -15,7 +15,7 @@ from .volatility_factors import BetaSSEIFactor, Vol250DFactor, ResidualVolSSEIFa
 from .fund_basic_factors import FundInfo, InMarketFundInfo, CloseFundInfo, FilteredFundInfoI, TradingDay, IndexInfo, FundManagerInfo, \
                                 FundConvInfo, FundBenchmarkInfo, FilteredFundInfoWhole, ActiveFundInfo, IndexCloseDaily, IndexRetDaily, \
                                 IndexRetWeekly, IndexRetMonthly, FundNavDaily, FundRetDaily, FundSize, FundSizeCombine, FundCompanyHold, \
-                                FundPersonHold, FundRetDailyModify, FundRetWeeklyModify, FundRetMonthlyModify, FundNavDailyModify, \
+                                FundRetDailyModify, FundRetWeeklyModify, FundRetMonthlyModify, FundNavDailyModify, FundInfoAsset, \
                                 FundNavWeeklyModify, FundNavMonthlyModify, Macroeco, FundBenchmarkRet, FundBenchmarkPrice, FundPersonalHold
 from .fund_derived_factors import FundAlive, TradeYear, FeeRate, AlphaBetaDaily3yI, AlphaDaily3yI, BetaDaily3yI, TrackerrDaily3yI, InfoRatioDaily3yI, \
                                   MddDaily3y, TreynorDaily3yI, DownriskDaily3y, RetOverPeriodDaily3y, AnnualRetDaily3y, AnnualVolDaily3y, \
@@ -24,12 +24,15 @@ from .fund_derived_factors import FundAlive, TradeYear, FeeRate, AlphaBetaDaily3
                                   SharpeDaily1y, AnnualRetDailyHistory, AnnualVolDailyHistory, AnnualRetMonthlyHalfY, AnnualVolMonthlyHalfY, \
                                   SharpeMonthlyHalfY, ContinueRegValue, TotalRetDailyHistory, MddDailyHistory, RecentMonthRet, DownsideStdDailyHistory, \
                                   FundClAlphaBetaHistoryWeekly, FundClAlphaHistoryWeekly, FundClBetaHistoryWeekly, FundClAlphaBeta1YWeekly, FundClAlpha1YWeekly, \
-                                  FundClBeta1YWeekly, ManagerIndex, ManagerBestFund, ManagerIndexRetDaily, ManagerIndexWeekly, ManagerIndexRetWeekly, \
+                                  FundClBeta1YWeekly, AlphaMdd3yI, WinRateMonthlyI, WinRateMonthlyTop50, WinRateMonthlyTop75, \
+                                  ManagerIndex, ManagerBestFund, ManagerIndexRetDaily, ManagerIndexWeekly, ManagerIndexRetWeekly, \
                                   ManagerIndexMonthly, ManagerIndexRetMonthly, MngAnnualRetDailyHistory, MngAnnualRetDaily1Y, MngAnnualRetDaily3Y, \
                                   MngTotalRetDailyHistory, MngMddDailyHistory, MngAnnualVolDailyHistory, MngDownsideStdDailyHistory, MngDownsideStdMonthlyHistory, \
                                   MngFundTypeTradingDays, MngClAlphaBetaWeekly1Y, MngClAlphaWeekly1Y, MngClBetaWeekly1Y, MngClAlphaBetaWeeklyHistory, \
                                   MngClAlphaWeeklyHistory, MngClBetaWeeklyHistory, MngFundSize
 
+from .fund_derived_score import MngScoreV1, FundMngScoreV1, RetAbilityFundScore, RiskAbilityFundScore, StableAbility, SelectTimeAbility, SelectStockAbility 
+
 conf = SurfingConfigurator().get_aws_settings()
 # 在to_parquet/read_parquet中通过storage_options传递如下参数的方法不好用，这里直接设置环境变量
 os.environ['AWS_ACCESS_KEY_ID'] = conf.aws_access_key_id
@@ -51,7 +54,7 @@ for obj in (GrossMarginFactor, ReturnOnAssetsFactor, ReturnOnEquityFactor, Turno
 fund_basic_factor = [FundInfo, InMarketFundInfo, CloseFundInfo, FilteredFundInfoI, TradingDay, IndexInfo, FundManagerInfo,
                      FundConvInfo, FundBenchmarkInfo, FilteredFundInfoWhole, ActiveFundInfo, IndexCloseDaily, IndexRetDaily,
                      IndexRetWeekly, IndexRetMonthly, FundNavDaily, FundRetDaily, FundSize, FundSizeCombine, FundCompanyHold,
-                     FundPersonHold, FundRetDailyModify, FundRetWeeklyModify, FundRetMonthlyModify, FundNavDailyModify,
+                     FundRetDailyModify, FundInfoAsset, FundRetWeeklyModify, FundRetMonthlyModify, FundNavDailyModify,
                      FundNavWeeklyModify, FundNavMonthlyModify, Macroeco, FundBenchmarkRet, FundBenchmarkPrice, FundPersonalHold]
 
 fund_derived_factor = [FundAlive, TradeYear, FeeRate, AlphaBetaDaily3yI, AlphaDaily3yI, BetaDaily3yI, TrackerrDaily3yI, InfoRatioDaily3yI,
@@ -65,4 +68,9 @@ fund_derived_factor = [FundAlive, TradeYear, FeeRate, AlphaBetaDaily3yI, AlphaDa
                        ManagerIndexMonthly, ManagerIndexRetMonthly, MngAnnualRetDailyHistory, MngAnnualRetDaily1Y, MngAnnualRetDaily3Y,
                        MngTotalRetDailyHistory, MngMddDailyHistory, MngAnnualVolDailyHistory, MngDownsideStdDailyHistory, MngDownsideStdMonthlyHistory,
                        MngFundTypeTradingDays, MngClAlphaBetaWeekly1Y, MngClAlphaWeekly1Y, MngClBetaWeekly1Y, MngClAlphaBetaWeeklyHistory,
-                       MngClAlphaWeeklyHistory, MngClBetaWeeklyHistory, MngFundSize]
+                       MngClAlphaWeeklyHistory, MngClBetaWeeklyHistory, MngFundSize, AlphaMdd3yI, WinRateMonthlyI, WinRateMonthlyTop50, WinRateMonthlyTop75]
+
+fund_derived_score = [FundMngScoreV1,MngScoreV1,FundMngScoreV1, RetAbilityFundScore, RiskAbilityFundScore, StableAbility, SelectTimeAbility, SelectStockAbility ]
+
+fund_append_update_factor = [AlphaBetaDaily3yI, TrackerrDaily3yI, AlphaBetaDaily1yI, TrackerrDaily1yI, FundClAlphaBetaHistoryWeekly, FundClAlphaBeta1YWeekly,
+                             ManagerIndex, MngClAlphaBetaWeekly1Y, MngClAlphaBetaWeeklyHistory, MngScoreV1]
\ No newline at end of file
